﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;

namespace CompositeChart
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Declare a composite chart type
            this.ultraChart1.ChartType = ChartType.Composite;
            
            //Create a chart area
            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            AxisItem axisY = new AxisItem();
            axisY.Extent = 20;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.Labels.SeriesLabels.Format = AxisSeriesLabelFormat.SeriesLabel;
            axisY.Labels.SeriesLabels.FormatString = "<SERIES_VALUE>";
            axisY.LineColor = Color.Black;
            area.Axes.Add(axisY);


            //Create a X axis of data type String
            //It is very importatnt to set poperty SetLabelAxisType = ContinuousData
            //because we intend to use LineChart
            AxisItem axisX = new AxisItem();
            axisX.DataType = AxisDataType.String;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            area.Axes.Add(axisX);


            //Create a ChartLayer
            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.LineChart;
            myColumnLayer.ChartArea = area;

            //Create a DataTable with sample data
            //This data will be used like DataSource for our composite chart
            DataTable dt = new DataTable();
            dt.Columns.Add("DateTime");
            dt.Columns.Add("Temp");
            dt.Columns.Add("Length");

            dt.Rows.Add("08/01/2011 07:10:21", 11.25, 10);
            dt.Rows.Add("08/01/2011 07:10:22", 11.27, 11);
            dt.Rows.Add("08/01/2011 07:10:23", 11.23, 14);
            dt.Rows.Add("08/01/2011 07:10:24", 11.28, 12);
            dt.Rows.Add("08/01/2011 07:10:25", 11.25, 13);
            

            NumericSeries series1 = new NumericSeries();
            series1.DataBind(dt, "Length", "Temp");
            series1.PEs.Add(new PaintElement(Color.Red));
            series1.Label = "My line chart";
            myColumnLayer.Series.Add(series1);
            ultraChart1.CompositeChart.Series.Add(series1);

            LineAppearance la = new LineAppearance(ultraChart1);
            la.IconAppearance.Icon = SymbolIcon.Circle;
            la.IconAppearance.IconSize = SymbolIconSize.Large;
            la.LineStyle.EndStyle = LineCapStyle.DiamondAnchor;

            LineChartAppearance dd = new LineChartAppearance();
            dd.LineAppearances.Add(la);
            myColumnLayer.ChartTypeAppearance = dd;

            // Set axis for each Chart Layer
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);

            CompositeLegend myLegend = new CompositeLegend();
            myLegend.ChartLayers.Add(myColumnLayer);
            myLegend.Bounds = new Rectangle(0, 85, 15, 15);
            myLegend.BoundsMeasureType = MeasureType.Percentage;
            myLegend.PE.ElementType = PaintElementType.Gradient;
            myLegend.PE.FillGradientStyle = GradientStyle.ForwardDiagonal;
            myLegend.PE.Fill = Color.CornflowerBlue;
            myLegend.PE.FillStopColor = Color.Transparent;
            myLegend.Border.CornerRadius = 10;
            myLegend.Border.Thickness = 1;

            this.ultraChart1.CompositeChart.Legends.Add(myLegend);
        }
    }
}